Image Name
  The name of the image.
Image Description
  A description of the image.
Source Type
  Uploading the image from a local file or from a specified URL.
Location
  If uploading the image via a HTTP URL the image location must be accessible to the Image Service and be a URL direct to the image binary.
Format
  Select the format of the disk from the drop down menu.
Kernel
  Select the kernel to run from the drop down menu.
Ramdisk
  Select the Ramdisk from the drop down menu.
Architecture
  The architecture of the image.
Minimum Disk
  Amount of disk space in GB that is required to boot the image.
Minimum RAM
  Amount of RAM in MB that is required to boot the image.
Visibility
  The access permission for the image.
Protected
  If set to 'Yes' then the image cannot be deleted.